@@ -119,8 +119,8 @@ class LinearDrawer(AbstractDrawer):
         """
         # Use the superclass' instantiation method
         AbstractDrawer.__init__(self, parent, pagesize, orientation,
-                                  x, y, xl, xr, yt, yb, start, end,
-                                  tracklines, cross_track_links)
+                                x, y, xl, xr, yt, yb, start, end,
+                                tracklines, cross_track_links)
 
         # Useful measurements on the page
         self.fragments = fragments
@@ -995,27 +995,27 @@ class LinearDrawer(AbstractDrawer):
         pos, val = data[0]
         lastfrag, lastx = self.canvas_location(pos)
         lastx += self.x0        # Start xy co-ords
-        lasty = trackheight * (val - midval) / resolution + \
-                self.fragment_lines[lastfrag][0] + ctr
+        lasty = (trackheight * (val - midval) / resolution
+                 + self.fragment_lines[lastfrag][0] + ctr)
         lastval = val
         # Add a series of lines linking consecutive data points
         for pos, val in data:
             frag, x = self.canvas_location(pos)
             x += self.x0        # next xy co-ords
-            y = trackheight * (val - midval) / resolution + \
-                self.fragment_lines[frag][0] + ctr
+            y = (trackheight * (val - midval) / resolution
+                 + self.fragment_lines[frag][0] + ctr)
             if frag == lastfrag:    # Points on the same fragment: draw the line
                 line_elements.append(Line(lastx, lasty, x, y,
                                           strokeColor=graph.poscolor,
                                           strokeWidth=graph.linewidth))
             else:   # Points not on the same fragment, so interpolate
-                tempy = trackheight * (val - midval) / resolution + \
-                        self.fragment_lines[lastfrag][0] + ctr
+                tempy = (trackheight * (val - midval) / resolution
+                         + self.fragment_lines[lastfrag][0] + ctr)
                 line_elements.append(Line(lastx, lasty, self.xlim, tempy,
                                           strokeColor=graph.poscolor,
                                           strokeWidth=graph.linewidth))
-                tempy = trackheight * (val - midval) / resolution + \
-                        self.fragment_lines[frag][0] + ctr
+                tempy = (trackheight * (val - midval) / resolution
+                         + self.fragment_lines[frag][0] + ctr)
                 line_elements.append(Line(self.x0, tempy, x, y,
                                           strokeColor=graph.poscolor,
                                           strokeWidth=graph.linewidth))
@@ -1201,7 +1201,7 @@ class LinearDrawer(AbstractDrawer):
         return fragment, x_offset
 
     def _draw_sigil_box(self, bottom, center, top, x1, x2, strand, **kwargs):
-        """Draw BOX sigil."""
+        """Draw BOX sigil (PRIVATE)."""
         if strand == 1:
             y1 = center
             y2 = top
@@ -1214,7 +1214,7 @@ class LinearDrawer(AbstractDrawer):
         return draw_box((x1, y1), (x2, y2), **kwargs)
 
     def _draw_sigil_octo(self, bottom, center, top, x1, x2, strand, **kwargs):
-        """Draw OCTO sigil, a box with the corners cut off."""
+        """Draw OCTO sigil, a box with the corners cut off (PRIVATE)."""
         if strand == 1:
             y1 = center
             y2 = top
@@ -1273,7 +1273,7 @@ class LinearDrawer(AbstractDrawer):
                        **kwargs)
 
     def _draw_sigil_arrow(self, bottom, center, top, x1, x2, strand, **kwargs):
-        """Draw ARROW sigil."""
+        """Draw ARROW sigil (PRIVATE)."""
         if strand == 1:
             y1 = center
             y2 = top
@@ -1289,7 +1289,7 @@ class LinearDrawer(AbstractDrawer):
         return draw_arrow((x1, y1), (x2, y2), orientation=orientation, **kwargs)
 
     def _draw_sigil_big_arrow(self, bottom, center, top, x1, x2, strand, **kwargs):
-        """Draw BIGARROW sigil, like ARROW but straddles the axis."""
+        """Draw BIGARROW sigil, like ARROW but straddles the axis (PRIVATE)."""
         if strand == -1:
             orientation = "left"
         else:
